# $name

#### Generated via pepsin

### Usage

How to run

Install  pepsin library
```shell
$ pip install pepsin
```

1. Run project

```shell
$ pepsin run start
```

2. Install libraries

```shell
$ pepsin install django
```
